.\" -*-nroff-*-
.\" ====================================================================
.\"  @Troff-man-file{
.\"     author          = "Nelson H. F. Beebe",
.\"     version         = "1.00",
.\"     date            = "08 April 2001",
.\"     time            = "12:36:26 MDT",
.\"     filename        = "pstotiff.man",
.\"     address         = "Center for Scientific Computing
.\"                        University of Utah
.\"                        Department of Mathematics, 322 INSCC
.\"                        155 S 1400 E RM 233
.\"                        Salt Lake City, UT 84112-0090
.\"                        USA",
.\"     telephone       = "+1 801 581 5254",
.\"     FAX             = "+1 801 585 1640, +1 801 581 4148",
.\"     URL             = "http://www.math.utah.edu/~beebe",
.\"     checksum        = "52550 310 1127 8350",
.\"     email           = "beebe@math.utah.edu, beebe@acm.org,
.\"                        beebe@computer.org, beebe@ieee.org
.\"                        (Internet)",
.\"     codetable       = "ISO/ASCII",
.\"     keywords        = "TIFF (Tag Image File Format);
.\"                        portable anymap; portable bitmap;
.\"                        PostScript",
.\"     supported       = "yes",
.\"     docstring       = "This is the UNIX manual page document for
.\"                        pstotiff.
.\"
.\"                        The checksum field above contains a CRC-16
.\"                        checksum as the first value, followed by the
.\"                        equivalent of the standard UNIX wc (word
.\"                        count) utility output of lines, words, and
.\"                        characters.  This is produced by Robert
.\"                        Solovay's checksum utility.",
.\"  }
.\" ====================================================================
.TH PSTOTIFF 1 "08 April 2001" "Version 1.00"
.if t .ds Ps P\s-2OST\s0S\s-2CRIPT\s0
.if n .ds Ps PostScript
.\"======================================================================
.SH NAME
pstotiff \- convert (Encapsulated) PostScript files to TIFF bitmap files
.\"======================================================================
.SH SYNOPSIS
.B pstotiff
[
.B \-?
]
[
.B \-crop
]
[
.B \-debug
]
[
.BI \-extension " name"
]
.if n .ti +9n
[
.BI \-gamma " float-value"
]
[
.B \-help
]
[
.B \-icon
]
.if n .ti +9n
.if t .ti +\w'\fBpstotiff\fP\ 'u
[
.BI \-margin " pixels"
]
[
.B \-norun
]
[
.BI \-resolution " dpi"
]
.if n .ti +9n
[
.B \-version
]
[
.BI \-W "component,option"
]
.if n .ti +9n
.if t .ti +\w'\fBpstotiff\fP\ 'u
.I "\*(Ps\&-files"
.\"======================================================================
.SH DESCRIPTION
.B pstotiff
converts one or more input
.I "(Encapsulated) \*(Ps\&"
files to output
.I "Tag Image File Format (TIFF)"
lossless compressed bitmap files.
.PP
For maximal color fidelity, bitmaps are produced
in 24-bit color mode, with 16,777,216 possible
colors.
.PP
For each file given on the command line, an output
file is written with the same basename as the
input file, but with extension
.IR tiff ,
or the name specified by the
.B \-extension
option.
.PP
With the
.B \-icon
option, small companion files with the same name
are also written in a subdirectory
.IR icons ,
which is created if necessary.
.PP
If no files are given on the command line, then
.I stdin
is read, and
.I stdout
is written, and no icon file can be produced.
.PP
.B pstotiff
is a convenient interface to
.BR gs (1),
.BR pngtopnm (1),
.BR pnmcrop (1),
.BR pnmmargin (1),
and
.BR pnmtotiff (1),
which do the real work.
.\"======================================================================
.SH OPTIONS
Command-line options may be abbreviated to a
unique leading prefix.
.PP
To avoid confusion with options, if a filename
begins with a hyphen, it must be disguised by a
leading absolute or relative directory path, e.g.
.I /tmp/-foo.eps
or
.IR ./-foo.eps .
.PP
Options may begin with either UNIX-style single
hyphens, or GNU/POSIX-style double hyphens, and
may be abbreviated to any unique prefix.
.\"-----------------------------------------------
.TP \w'\fB\-gamma\fP\ \fIfloat-value\fP'u+3n
.B \-crop
Crop the image to remove edges that are the
background color.
.\"-----------------------------------------------
.TP
.B \-debug
Turn on debug tracing.
.\"-----------------------------------------------
.TP
.BI \-extension " name"
Replace the default output file extension,
.IR tiff ,
with
.IR name .
.\"-----------------------------------------------
.TP
.BI \-gamma " float-value"
Specify an image gamma correction as a
floating-point number.  Small values darken the
image, and large values lighten it.  Typical
values are in the range 0.5 .\|. 3.0.
.IP
.RI [Default: " 1.0" ]
.\"-----------------------------------------------
.TP
.B \-?
.br
.ns
.TP
.B \-help
Display a brief help message on
.IR stdout ,
and exit with a success status code (0 on UNIX).
.\"-----------------------------------------------
.TP
.B \-icon
Produce icon files as well as TIFF files.  An icon
file is just a low-resolution (12dpi) bitmap that
may be useful as a compact representation of what
is in the TIFF file.
.IP
In filter mode (no files on the command line),
this option is ignored.
.\"-----------------------------------------------
.TP
.BI \-margin " pixels"
Add a background margin of width
.I pixels
to the output image.  This option is usually
specified together with
.BR \-crop .
.\"-----------------------------------------------
.TP
.B \-norun
Show on
.I stdout
the commands that would be executed, but do not
run them.
.IP
Use this option to trap the complex command
pipelines for further private customization.
.\"-----------------------------------------------
.TP
.BI \-resolution " dpi"
Set the output bitmap resolution to
.I dpi
dots per inch.
.IP
.RI [Default: " 100" " dpi, suitable only for screen resolution]."
.\"-----------------------------------------------
.TP
.B \-version
Display program version numbers and dates on
.IR stdout ,
and exit with a success status code (0 on UNIX).
.\"-----------------------------------------------
.TP
.BI \-W "component,option"
Pass
.I option
to the program
.IR component ,
which must be one of
.IR gs ,
.IR pngtopnm ,
.IR pnmcrop ,
.IR pnmmargin ,
or
.IR pnmtotiff .
.IP
This option, a POSIX convention, provides a
general way for a user to pass options to programs
invoked by another program.  The value
.I option
is passed
.I after
any generated in response to options supplied to
.BR pstotiff .
For example,
.BI \-W pnmmargin,-black
would cause any added margin to be colored black.
.\"======================================================================
.SH "SEE ALSO"
.BR epsutil (1),
.BR gs (1),
.BR gimp (1),
.BR photoshop (1),
.BR pngtopnm (1),
.BR pnmcrop (1),
.BR pnmmargin (1),
.BR pnmtotiff (1),
.BR pstojpeg (1),
.BR pstopng (1),
.BR xv (1).
.PP
.IR "Tag Image File Format (TIFF) Specification Revision 5.0" ,
Aldus Corporation, Seattle, WA, and
Microsoft Corporation, Redmond, WA, August 1988.
.PP
David C. Kay and John R. Levine,
.IR "Graphics File Formats" ,
Chapter 5,
Windcrest/McGraw-Hill, Blue Ridge Summit, PA, 1992,
ISBN 0-8306-3060-0 (hardcover), 0-8306-3059-7 (paperback).
.PP
Steve Rimmer,
.IR "Bit-Mapped Graphics" ,
Windcrest/McGraw-Hill, Blue Ridge Summit, PA, 1993,
ISBN 0-8306-4209-9 (hardback), 0-8306-4208-0 (paperback).
.PP
Gnter Born,
.IR "The File Formats Handbook" ,
Chapter 27,
International Thomson Computer Press, Boston, MA, 1995,
ISBN 1-85032-117-5 (hardback), 1-85032-128-0 (paperback).
.PP
John Miano,
.IR "The programmer's guide to compressed image files: JPEG, TIFF, GIF, XBM, BMP" ,
Addison-Wesley Longman,
Harlow, Essex, England 1999,
ISBN 0-201-60443-4.
.\"======================================================================
.SH AUTHOR
.nf
Nelson H. F. Beebe, Ph.D.
Center for Scientific Computing
University of Utah
Department of Mathematics, 322 INSCC
155 S 1400 E RM 233
Salt Lake City, UT 84112-0090
Tel: +1 801 581 5254
FAX: +1 801 585 1640, +1 801 581 4148
Email: \fCbeebe@math.utah.edu\fP, \fCbeebe@acm.org\fP,
       \fCbeebe@computer.org\fP, \fCbeebe@ieee.org\fP
WWW URL: \fChttp://www.math.utah.edu/~beebe\fP
.fi
.\"==============================[The End]==============================
.\" This is for GNU Emacs file-specific customization:
.\" Local Variables:
.\" fill-column: 50
.\" End:
